(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     27597,        708]*)
(*NotebookOutlinePosition[     29088,        753]*)
(*  CellTagsIndexPosition[     29044,        749]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[BoxData[
    \(\(Off[General::spell, General::spell1, Set::wrsym, SetDelayed::write, 
        SetDelayed::wrsym, Syntax::newl];\)\)], "Input",
  CellFrame->{{0, 0}, {0.5, 0}},
  InitializationCell->True],

Cell[BoxData[
    \(timer[] := 
      \((Print["\<Elapsed time = \>", Round[AbsoluteTime[] - av$bt], 
          "\< sec.\>"])\); reset[] := \((av$bt = AbsoluteTime[]; )\); \)], 
  "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(names = Get[\ \ "\<AVFnames\>"];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[""], "Input",
  CellFrame->{{0, 0}, {0, 0.5}}],

Cell["(*ALGEBRA PRELIMINARIES.*)", "Input",
  FormatType->TextForm],

Cell[BoxData[
    \(makeelements[av$g_] := 
      \((av$s30[av$g]; Unprotect[eldim, elements]; elements = av$g; 
        eldim = Length[elements]; \t\t\n\nProtect[eldim, elements]; 
        adjlist = elements)\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(makealgebra[av$g_, av$g1_:  True] := 
      Block[{av$1}, 
        \((Unprotect[algebra]; av$1 = Length[av$g[\([1]\)]]; 
          If[av$g1, algebra = av$g; 
            Do[algebra[\([1, i$1]\)] = 
                \(algebra[\([i$1, 1]\)] = elements[\([i$1]\)]\), {i$1, 
                av$1}]; Protect[algebra]; Return[]]; 
          makeelements[Prepend[elements, av$g1]]; av$1 = av$1 + 1; 
          algebra = IdentityMatrix[av$1]; 
          Do[algebra[\([1, i$1]\)] = 
              \(algebra[\([i$1, 1]\)] = elements[\([i$1]\)]\), {i$1, av$1}]; 
          Do[algebra[\([i$3 + 1, i$2 + 1]\)] = av$g[\([i$3, i$2]\)]; 
            algebra[\([i$2 + 1, i$3 + 1]\)] = av$g[\([i$2, i$3]\)], {i$3, 
              av$1 - 1}, {i$2, av$1 - 1}]; Protect[algebra]; )\)]\)], "Input",\

  InitializationCell->True],

Cell[BoxData[
    \(mtx[av$g_:  algebra] := MatrixForm[av$g]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(generic[] := 
      \((symm = 
          Flatten[Table[
              sy\_\(j$1, j$2, j$3\), {j$1, 0, eldim - 1}, {j$2, eldim - 1}, {
                j$3, j$2, eldim - 1}]]; \n
        skew = Flatten[
            Table[sk\_\(j$1, j$2, j$3\), {j$1, 0, eldim - 1}, {j$2, 
                eldim - 2}, {j$3, j$2 + 1, eldim - 1}]]; \n
        Table[Which[j$2*j$3 == 0, elements[\([j$2 + 1]\)], j$2 == j$3, 
            Sum[\(sy\_\(j$1, j$2, j$3\)\) elements[\([j$1 + 1]\)], {j$1, 0, 
                eldim - 1}], j$2 < j$3, 
            Sum[\((sy\_\(j$1, j$2, j$3\) + \ sk\_\(j$1, j$2, j$3\))\) 
                elements[\([j$1 + 1]\)], {j$1, 0, eldim - 1}], j$2 > j$3, 
            Sum[\((sy\_\(j$1, j$3, j$2\) - \ sk\_\(j$1, j$3, j$2\))\) 
                elements[\([j$1 + 1]\)], {j$1, 0, eldim - 1}]], {j$2, 0, 
            eldim - 1}, {j$3, 0, eldim - 1}])\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[""], "Input",
  CellFrame->{{0, 0}, {0, 0.5}}],

Cell["(*DIFFERENTIAL FORM PRELIMINARIES.*)", "Input",
  FormatType->TextForm],

Cell[BoxData[
    \(SetAttributes[Wedge, {Flat, OneIdentity}]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(makeforms[av$g_] := 
      \((av$s30[av$g]; 
        Unprotect[fmdim, forms, dforms, fderiv, sderiv, natural, av$c, av$bs, 
          av$cs]; av$g1 = 
          DeleteCases[av$g, av$21_ /; MemberQ[dscalars, av$21]]; 
        forms = Join[av$g1, dscalars]; fmdim = Length[forms]; 
        dforms = Table[av$s20[d, forms[\([i$1]\)]], {i$1, fmdim - scdim}]; 
        av$bs = Join[{av$fm}, forms, dforms]; \t\n
        fderiv = 
          Flatten[Join[{av$fm -> 0}, 
              Table[{dforms[\([i$2]\)] -> 0, 
                  forms[\([i$2]\)] -> dforms[\([i$2]\)]}, {i$2, 
                  fmdim - scdim}], 
              Table[forms[\([fmdim - scdim + i$1]\)] -> 0, {i$1, scdim}]]]; 
        sderiv = 
          Table[Dt[scalars[\([i$1]\)]] -> dscalars[\([i$1]\)], {i$1, scdim}]; 
        If[av$fg, 
          natural = Table[dforms[\([i$1]\)] -> 0, {i$1, fmdim - scdim}]; 
          makedrules[natural]]; av$fg = True; 
        av$cs = Table[av$c\_i$1, {i$1, fmdim}]; makevectors[]; 
        Protect[fmdim, forms, dforms, fderiv, sderiv, natural, av$c, av$bs, 
          av$cs]; forms)\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(makevectors[] := 
      \((Do[v1\_i$1 = \(v2\_i$1 = \(v3\_i$1 = \(v4\_i$1 = 0\)\)\); 
          v1\_i$1 =. ; v2\_i$1 =. ; v3\_i$1 =. ; v4\_i$1 =. , {i$1, fmdim}]; 
        \nvec1 = av$cs /. av$c -> v1; vec2 = av$cs /. av$c -> v2; 
        vec3 = av$cs /. av$c -> v3; vec4 = av$cs /. av$c -> v4; )\)\)], 
  "Input",
  InitializationCell->True],

Cell[BoxData[
    \(makescalars[av$g_] := 
      \((av$s30[av$g]; Unprotect[scdim, scalars, dscalars]; 
        av$55 = Take[forms, fmdim - scdim]; scalars = av$g; 
        scdim = Length[scalars]; 
        dscalars = Table[av$s20[d, scalars[\([i$1]\)]], {i$1, scdim}]; 
        av$fg = False; \nmakeforms[av$55]; Protect[scdim, scalars, dscalars]; 
        scalars)\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(makecoords[av$g_] := 
      \((Unprotect[coords, coordsdim, depend, topartials]; \t\t
        Do[Format[D[av$z_[depend], coords[\([j$3]\)]]] =. , {j$3, 
            coordsdim}]; \n\t\t
        Do[Format[D[D[av$z_[depend], coords[\([j$3]\)]], coords[\([j$4]\)]]]
               =. , {j$3, coordsdim}, {j$4, j$3, coordsdim}]; 
        makescalars[Join[av$g, Complement[scalars, av$g]]]; coords = av$g; 
        coordsdim = Length[coords]; depend = coords /. List -> Sequence; \t
        Do[Format[D[av$z_[depend], coords[\([j$3]\)]]] = 
            Subscript[av$z, coords[\([j$3]\)]], {j$3, coordsdim}]; \n\t\t
        Do[Format[D[D[av$z_[depend], coords[\([j$3]\)]], coords[\([j$4]\)]]]
               = Subscript[av$z, 
              ToString[coords[\([j$3]\)]]<>ToString[\ coords[\([j$4]\)]]], {
            j$3, coordsdim}, {j$4, j$3, coordsdim}]; \n\t
        topartials = 
          Table[dscalars[\([j$1]\)] -> 
              Sum[D[\(scalars[\([j$1]\)]\)[depend], coords[\([j$2]\)]]\ 
                  dscalars[\([j$2]\)], {j$2, coordsdim}], {j$1, 
              1 + coordsdim, scdim}]; 
        av$id := IdentityMatrix[fmdim - scdim + coordsdim]; \n
        D\_av$gu_[av$gx_] := 
          \((av$dr = drules; makedrules[topartials]; 
            If[Head[av$gu] === Integer, 
              av$ret = 
                av$id[\([fmdim - scdim + av$gu]\)]\[SmallCircle]d[av$gx], 
              av$ret = 
                Flatten[
                    Extract[av$id, fmdim - scdim + Position[coords, av$gu]]]
                    \[SmallCircle]d[av$gx]]; makedrules[av$dr]; av$ret)\); 
        makedrules[Join[drules, topartials]]; 
        Protect[coords, coordsdim, depend, topartials]; coords)\)\)], "Input",\

  InitializationCell->True],

Cell[BoxData[
    \(makeframe[av$g11_] := 
      \((Unprotect[frame, frdim]; frdim = Length[av$g11]; 
        signature = \(av$31 = \(av$32 = {}\)\); 
        Do[av$33 = av$g11[\([i$7]\)]; 
          If[Head[av$33] === Times, AppendTo[av$31, \(-av$33\)]; 
            AppendTo[av$32, \(-1\)], AppendTo[av$31, av$33]; 
            AppendTo[av$32, 1]], {i$7, frdim}]; frame = Sort[av$31]; 
        Do[sig[i$7] = 
            \(Extract[av$32, Position[av$31, frame[\([i$7]\)]]]\)[\([1]\)]; 
          AppendTo[signature, sig[i$7]], {i$7, frdim}]; av$fg = False; 
        makeforms[Join[frame, Complement[forms, frame]]]; av$s82[]; 
        Protect[frame, frdim]; frame)\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(av$s82[] := 
      \((\nav$star[{av$fm}] = {1, frame}; 
        av$star[frame] = {\ Product[sig[i$3], {i$3, frdim}], {av$fm}}; 
        If[frdim == 1, Return[]]; \n
        Do[av$star[{frame[\([i$1]\)]}] = {
              \((\(-1\))\)^\((i$1 - 1)\) sig[i$1]\ , Delete[frame, {i$1}]}, {
            i$1, frdim}]; If[frdim == 2, Return[]]; \n
        Do[av$star[{frame[\([i$1]\)], frame[\([i$2]\)]}] = {
              \((\(-1\))\)^\((i$1 + i$2 - 1)\) sig[i$1]\ sig[i$2], 
              Delete[frame, {{i$1}, {i$2}}]}, {i$1, frdim - 1}, {i$2, 
            i$1 + 1, frdim}]; If[frdim == 3, Return[]]; \n
        Do[av$star[{frame[\([i$1]\)], frame[\([i$2]\)], frame[\([i$3]\)]}] = {
              \((\(-1\))\)^\((i$1 + i$2 + i$3)\) sig[i$1]\ sig[i$2] sig[i$3], 
              Delete[frame, {{i$1}, {i$2}, {i$3}}]}, {i$1, frdim - 2}, {i$2, 
            i$1 + 1, frdim - 1}, {i$3, i$2 + 1, frdim}]; 
        If[frdim == 4, Return[]]; \n
        Do[av$star[{frame[\([i$1]\)], frame[\([i$2]\)], frame[\([i$3]\)], 
                frame[\([i$4]\)]}] = {
              \((\(-1\))\)^\((i$1 + i$2 + i$3 + i$4)\) sig[i$1]\ sig[i$2] 
                sig[i$3] sig[i$4], 
              Delete[frame, {{i$1}, {i$2}, {i$3}, {i$4}}]}, {i$1, 
            frdim - 3}, {i$2, i$1 + 1, frdim - 2}, {i$3, i$2 + 1, 
            frdim - 1}, {i$4, i$3 + 1, frdim}]; If[frdim == 5, Return[]]; 
        Do[av$star[{frame[\([i$1]\)], frame[\([i$2]\)], frame[\([i$3]\)], 
                frame[\([i$4]\)], frame[\([i$5]\)]}] = {
              \((\(-1\))\)^\((i$1 + i$2 + i$3 + i$4 + i$5 - 1)\) sig[i$1]\ 
                sig[i$2] sig[i$3] sig[i$4] sig[i$5], 
              Delete[frame, {{i$1}, {i$2}, {i$3}, {i$4}, {i$5}}]}, {i$1, 
            frdim - 4}, {i$2, i$1 + 1, frdim - 3}, {i$3, i$2 + 1, 
            frdim - 2}, {i$4, i$3 + 1, frdim - 1}, {i$5, i$4 + 1, frdim}]; 
        If[frdim == 6, Return[]]; )\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[""], "Input",
  CellFrame->{{0, 0}, {0, 0.5}}],

Cell[BoxData[
    \( (*CALCULATIONS*) \)], "Input"],

Cell[BoxData[
    \(in[av$g_] := 
      Block[{av$1, av$2}, 
        \((If[Head[av$g] === List, Return[av$g]]; av$1 = Expand[av$g]; 
          If[av$1 == 0, Return[{{av$0, {av$fm}, elements[\([1]\)]}}]]; 
          If[Head[av$1] =!= Plus, 
            av$1 = av$1 + av$0*av$fm\ *elements[\([1]\)]]; 
          av$2 = Apply[List, av$1]; Map[av$s1, av$2])\)]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(av$s1[av$g_] := 
      Block[{av$3, av$4, av$5, av$6, av$7}, 
        \((If[av$g === 1, Return[{1, {av$fm}, elements[\([1]\)]}], 
            av$4 = Apply[List, av$3\ \ av$g]]; 
          av$6 = Cases[av$4, 
              av$12_ /; 
                \((Head[av$12] === Wedge || MemberQ[av$bs, av$12])\)]; 
          av$99 = 1; 
          If[av$6 == {}, av$6 = {av$fm}; av$5 = av$4, av$6 = av$6[\([1]\)]; 
            av$5 = DeleteCases[av$4, av$6]; av$6 = av$6 /. Wedge -> List; 
            av$6 = av$s10[av$6]]; 
          av$7 = Cases[av$5, av$12_ /; MemberQ[elements, av$12]]; 
          If[av$7 == {}, av$7 = elements[\([1]\)], av$7 = av$7[\([1]\)]; 
            av$5 = DeleteCases[av$5, av$7]]; 
          If[av$5 == {av$3}, av$5 = av$99, 
            av$5 = Apply[Times, Join[{av$99}, av$5 /. av$3 -> 1]]]; {av$5, 
            av$6, av$7})\)]; \)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(av$s10[av$g_] := 
      Block[{av$8, av$9}, 
        \((If[Head[av$g] =!= List, Return[{av$g}], 
            av$8 = Cases[av$g, av$12_ /; MemberQ[forms, av$12]]; 
            av$9 = Cases[av$g, av$13_ /; MemberQ[dforms, av$13]]; 
            av$99 = Signature[av$8]; Join[Sort[av$8], Sort[av$9]]])\)]\)], 
  "Input",
  InitializationCell->True],

Cell[BoxData[
    \(out[av$g_] := 
      Block[{av$1, av$2}, 
        \((If[Head[av$g] =!= List, Return[av$g]]; 
          av$s2[i$8_] := 
            \((av$2 = av$g[\([i$8, 2]\)]; 
              If[Length[av$2] == 1, av$2 = av$2[\([1]\)], 
                av$2 = Apply[Wedge, av$2]])\); 
          av$1 = Sum[
              av$g[\([i$2, 1]\)] av$s2[i$2] av$g[\([i$2, 3]\)], {i$2, 
                Length[av$g]}]; 
          av$1 /. {av$fm -> 1, elements[\([1]\)] -> 1, av$0 -> 0})\)]\)], 
  "Input",
  InitializationCell->True],

Cell[BoxData[
    \(mult[av$g1_, av$g2_] := 
      Block[{av$1, av$2}, 
        \((If[av$g1 == 0 || av$g2 == 0, Return[0]]; 
          If[NumberQ[av$g1], Return[av$g1*out[in[av$g2]]]]; 
          If[NumberQ[av$g2], Return[av$g2*out[in[av$g1]]]]; 
          av$1 = Flatten[Outer[List, in[av$g1], in[av$g2], 1], 1]; 
          av$s4[av$g3_] := Thread[av$g3]; av$2 = Map[av$s4, av$1]; 
          out[Map[av$s3, av$2]])\)]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(av$s3[av$g_] := 
      Block[{av$4, av$5, av$6}, 
        \((av$5 = DeleteCases[Flatten[av$g[\([2]\)]], av$fm]; av$99 = 1; 
          av$5 = Switch[Length[av$5], 0, {av$fm}, 1, av$5, _, av$s10[av$5]]; 
          av$4 = av$99*Apply[Times, av$g[\([1]\)]]; 
          av$6 = algebra[
              \([\(Position[elements, av$g[\([3, 1]\)]]\)[\([1, 1]\)], 
                \(Position[elements, av$g[\([3, 2]\)]]\)[\([1, 1]\)]]\)]; {
            av$4, av$5, av$6})\)]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(Unprotect[NonCommutativeMultiply]; 
    NonCommutativeMultiply[av$g1_, av$g2_] := mult[av$g1, av$g2]; 
    Protect[NonCommutativeMultiply]; \)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(matmult[av$g1_, av$g2_] := 
      \((Table[Sum[
            av$g1[\([i$1, i$3]\)]**av$g2[\([i$3, i$2]\)], {i$3, 
              \(Dimensions[av$g1]\)[\([2]\)]}], {i$1, 
            \(Dimensions[av$g1]\)[\([1]\)]}, {i$2, 
            \(Dimensions[av$g2]\)[\([2]\)]}])\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(Unprotect[CircleTimes]; \n
    SetAttributes[CircleTimes, {Flat, OneIdentity}]; \n
    CircleTimes[av$g11_, av$g12_] := matmult[av$g11, av$g12]; \n
    Protect[CircleTimes]; \)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(factor[av$g1_, av$g2_] := 
      Block[{av$2, av$3, av$4}, 
        \((If[FreeQ[av$g2, av$g1], Return[0]]; 
          av$2 = {{av$0, {av$fm}, elements[\([1]\)]}}; av$3 = 1; 
          av$s6[av$g_] := 
            \((If[FreeQ[av$g[\([2]\)], av$g1], Return[]]; 
              If[Length[av$g[\([2]\)]] == 1, 
                AppendTo[av$2, {av$g[\([1]\)], {av$fm}, av$g[\([3]\)]}], 
                av$4 = Position[av$g[\([2]\)], av$g1]; 
                If[MemberQ[forms, av$g1], 
                  av$3 = \((\(-1\))\)^\((av$4[\([1, 1]\)] - 1)\)]; 
                AppendTo[
                  av$2, {av$3*av$g[\([1]\)], 
                    Delete[av$g[\([2]\)], av$4[\([1]\)]], av$g[\([3]\)]}]])
              \); Map[av$s6, in[av$g2]]; out[av$2])\)]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(contract[av$g3_, av$g4_] := 
      \((av$s14[\ av$g5_]\  := 
          \((If[Head[av$g5]\  =!= \ List, \ Return[av$s12[av$g3, \ av$g5]], \ 
              av$s14/@\ av$g5])\); av$s14[av$g4])\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(av$s12[av$g6_, av$g7_] := 
      Block[{av$1, av$2}, 
        \((av$2 = applydrules[av$g7]; 
          av$s16[av$g_] := 
            ReplacePart[av$g, av$g6[\([i$8]\)] av$g[\([1]\)], 1]; \n\t\t
          av$1 = {}; 
          Do[If[FreeQ[av$2, forms[\([i$8]\)]], Continue[], 
              AppendTo[av$1, Map[av$s16, av$s15[forms[\([i$8]\)], av$2]]]], {
              i$8, fmdim}]; out[Flatten[av$1, 1]])\)]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(\nav$s15[av$g1_, av$g2_] := 
      Block[{av$3, av$4}, 
        \((av$4 = {}; 
          av$s17[av$gs_] := 
            \((If[FreeQ[av$gs[\([2]\)], av$g1], Return[]]; 
              If[Length[av$gs[\([2]\)]] == 1, 
                AppendTo[av$4, {av$gs[\([1]\)], {av$fm}, av$gs[\([3]\)]}], 
                av$3 = Position[av$gs[\([2]\)], av$g1]; 
                AppendTo[
                  av$4, {\((\(-1\))\)^\((av$3[\([1, 1]\)] - 1)\)*
                      av$gs[\([1]\)], Delete[av$gs[\([2]\)], av$3[\([1]\)]], 
                    av$gs[\([3]\)]}]])\); Map[av$s17, in[av$g2]]; av$4)\)]
        \)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(Unprotect[SmallCircle]; 
    SetAttributes[SmallCircle, {Flat, OneIdentity}]; \ 
    SmallCircle[av$g1_, av$g2_] := contract[av$g1, av$g2]; 
    Protect[SmallCircle]; \)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(expand[av$g_] := Expand[av$g /. Wedge -> NonCommutativeMultiply]\)], 
  "Input",
  InitializationCell->True],

Cell[BoxData[
    \(collect[av$g_] := 
      Block[{av$1, av$2}, 
        \((av$1 = Collect[Expand[av$g] /. elements[\([1]\)] -> 1, elements]; 
          av$2 = av$1 /. {av$13_ /; MemberQ[elements, av$13] -> 0}; 
          av$1 - av$2 + av$2\ elements[\([1]\)])\)]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(coeffs[av$g1_] := 
      DeleteCases[Coefficient[collect[av$g1], elements], 0]\)], "Input",
  InitializationCell->True],

Cell["(*PRELIMINARIES FOR CALCULUS.*)", "Input",
  FormatType->TextForm],

Cell[BoxData[
    \(SetAttributes[av$0, Constant]; Protect[av$0]; \)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(drules = natural; Protect[drules]; \)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(makedrules[av$g_] := 
      Block[{av$4}, 
        \((av$4 = {}; 
          Do[If[Head[av$g[\([i$1]\)]] === Rule, 
              AppendTo[av$4, av$g[\([i$1]\)]]], {i$1, Length[av$g]}]; 
          av$98 = Complement[av$g, av$4]; 
          If[av$98 =!= {}, Print["\<Invalid input:   \>", av$98]; 
            Interrupt[], Unprotect[drules]; 
            If[av$g == {}, drules = natural, drules = av$g]; Protect[drules]; 
            drules])\)]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(applydrules[av$g2_] := expand[av$g2 /. drules]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(d[av$g8_] := 
      \((If[Head[av$g8] =!= List, Return[av$s21[av$g8]], Map[d, av$g8]])\)\)],
   "Input",
  InitializationCell->True],

Cell[BoxData[
    \(av$s21[av$g_] := 
      Block[{av$1, av$2, av$3, av$4, av$5, av$6, av$7, av$s9, av$s11}, 
        \((av$1 = in[av$g]; av$2 = av$s7[av$1]; 
          av$s9[av$g1_] := 
            \((\(i$3++\); av$7 = av$g1 /. fderiv; 
              If[av$7 === 0, Return[], av$6 = av$5; av$99 = 1; 
                av$4 = ReplacePart[av$3, 
                    av$s10[Delete[AppendTo[av$6, av$7], i$3]], 2]; 
                av$4[\([1]\)] = 
                  \((\(-1\))\)^\((i$3 - 1)\)*av$99*av$3[\([1]\)]; 
                AppendTo[av$2, av$4]])\); 
          av$s11[av$g2_] := 
            \((av$3 = av$g2; av$5 = av$g2[\([2]\)]; i$3 = 0; Map[av$s9, av$5])
              \); Map[av$s11, av$1]; out[av$2])\)]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(av$s7[av$g4_] := 
      Block[{av$8, av$9, av$11}, 
        \((av$11 = 0; 
          av$s8[av$g_] := 
            \((av$8 = Dt[av$g[\([1]\)]] /. sderiv; 
              av$8 = av$8 - 
                  \((av$8 /. av$12_ /; MemberQ[dscalars, av$12] -> 0)\); 
              If[av$8 === 0, Return[], 
                av$9 = {{av$0, {av$fm}, elements[\([1]\)]}, {1, 
                      av$g[\([2]\)], av$g[\([3]\)]}}; 
                av$11 = av$11 + mult[av$8, av$9]])\); Map[av$s8, av$g4]; 
          in[av$11])\)]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(da[av$g_] := applydrules[d[av$g]]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(lie[av$g1_, av$g2_] := 
      av$g1\[SmallCircle]d[av$g2] + da[av$g1\[SmallCircle]av$g2]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(liealgebra[] := 
      Block[{av$82, av$83, av$84}, av$84 = fmdim - scdim; av$82 = {}; 
        Do[If[FreeQ[drules, dforms[\([j$3]\)]], 
            AppendTo[av$82, dforms[\([j$3]\)]]], {j$3, av$84}]; 
        If[av$82 =!= {}, Print["\<Need drules for: \>", av$82]; Interrupt[]]; 
        av$83 = Sort[Take[forms, av$84]]; V =. ; 
        Print["\<order = \>", av$83]; \n
        brackets = 
          Flatten[Table[
              L[V\&\(av$83[\([j$1]\)]\), V\&\(av$83[\([j$2]\)]\)] -> 
                Sum[\(-Coefficient[da[av$83[\([j$3]\)]], 
                        av$83[\([j$1]\)]\[Wedge]av$83[\([j$2]\)]]\)\ 
                    V\&\(av$83[\([j$3]\)]\), {j$3, av$84}], {j$1, 
                av$84 - 1}, {j$2, j$1 + 1, av$84}]]; \nav$82 = brackets; 
        Do[av$82 = 
            ReplacePart[av$82, j$1, Position[av$82, av$83[\([j$1]\)]]], {j$1, 
            av$84}]; av$82]\)], "Input",
  InitializationCell->True],

Cell[BoxData[""], "Input",
  CellFrame->{{0, 0}, {0, 0.5}}],

Cell["(*AUXILIARY PROCEDURES.*)", "Input",
  FormatType->TextForm],

Cell[BoxData[
    \(av$s30[av$g16_] := 
      \((av$98 = 
          Cases[av$g16, 
            av$5_ /; 
              MemberQ[{Plus, Times, Power, Wedge, List}, Head[av$5]] || 
                NumericQ[av$5]]; 
        If[av$98 =!= {}, Print["\<Invalid input:   \>", av$98]; Interrupt[]])
        \)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(av$s20[av$g18_, av$g19_] := 
      Block[{av$1, av$2}, 
        \((av$1 = av$g19; While[Head[av$1] =!= Symbol, av$1 = av$1[\([1]\)]]; 
          av$2 = ToExpression[ToString[av$g18]<>ToString[av$1]]; 
          ReplacePart[av$g19, av$2, Position[av$g19, \ av$1]])\)]\)], "Input",\

  InitializationCell->True],

Cell[BoxData[
    \(prune[av$g1_, av$g2_] := 
      DeleteCases[av$g1, av$1_ /; FreeQ[av$g2, av$1]]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(setzero[av$g2_] := 
      \((av$s41[av$g1_] := av$g1 == 0; DeleteCases[Map[av$s41, av$g2], True])
        \)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(adL[av$41_, av$42_] := 
      \((av$s71[av$43_] := collect[av$41**av$43]; Map[av$s71, av$42])\)\)], 
  "Input",
  InitializationCell->True],

Cell[BoxData[
    \(adR[av$42_, av$41_] := 
      \((av$s72[av$43_] := collect[av$43**av$41]; Map[av$s72, av$42])\)\)], 
  "Input",
  InitializationCell->True],

Cell[BoxData[
    \(av$44 := 
      Table[av$49\_\(j$8, j$9\), {j$8, Length[adjlist]}, {j$9, 
          Length[adjlist]}]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(adjmat[av$46_] := 
      \((av$47 = av$44.adjlist - av$46; 
        av$47 = \ 
          setzero[Flatten[
              Table[coeffs[av$47[[i$1]]], {i$1, Length[av$47]}]]]; 
        av$45 = Flatten[Solve[av$47, Flatten[av$44]]]; av$44 /. av$45)\)\)], 
  "Input",
  InitializationCell->True],

Cell[BoxData[
    \(hs[av$g17_]\  := \ 
      \((If[Head[av$g17]\  =!= \ List, \ av$s83[applydrules[av$g17]], \ 
          hs\ /@\ av$g17])\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(av$s83[av$g15_] := 
      Block[{av$2}, 
        \((av$s81[av$g1_] := 
            \((av$2 = av$star[av$g1[\([2]\)]]; 
              ReplacePart[
                ReplacePart[av$g1, av$2[\([1]\)]\ av$g1[\([1]\)], {1}], 
                av$2[\([2]\)]\ , {2}])\); out[Map[av$s81, in[av$g15]]])\)]\)],
   "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\[Delta][av$g16_] := hs[hs[1]] hs[da[hs[av$g16]]]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(dot[av$g18_, \ av$g19_]\  := \ hs[hs[1]]*hs[av$g18**hs[av$g19]]\)], 
  "Input",
  InitializationCell->True],

Cell[BoxData[
    \(subspace[av$g_] := 
      \((cosub = av$g; sub = Complement[forms, cosub]; \n\ \ \ \ 
        tosub = \n\ \ \ \ \ \ \ 
          Flatten[\ 
            Table[{cosub[\([i$1]\)] -> 0, d[cosub[\([i$1]\)]] -> 0}, {i$1, \n
                \ \ \ \ \ \ \ \ \ \ \ \ Length[cosub]}]])\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(pullback[av$g_] := expand[av$g /. tosub]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(associators[i$7_] := 
      Block[{av$1, av$2, av$3}, av$2 = Length[algebra[\([1]\)]]; av$3 = 0; 
        Do[av$1 = 
            \((elements[\([i$4]\)]**elements[\([i$5]\)])\)**
                elements[\([i$6]\)] - 
              elements[\([i$4]\)]**
                \((elements[\([i$5]\)]**elements[\([i$6]\)])\); 
          If[av$1 =!= 0, 
            Print["\<(\>", elements[\([i$4]\)], "\<\>", elements[\([i$5]\)], 
              "\<)\>", elements[\([i$6]\)], "\< - \>", elements[\([i$4]\)], 
              "\<(\>", elements[\([i$5]\)], "\<\>", elements[\([i$6]\)], 
              "\<) = \>", av$1]; av$3 = av$3 + 1]; 
          If[av$3 + 1 > i$7, Return[]], {i$4, 2, av$2}, {i$5, 2, av$2}, {i$6, 
            2, av$2}]; Print["\<Done. Found:\>", av$3]]\)], "Input",
  InitializationCell->True],

Cell["(*SETTING UP A CLIFFORD ALGEBRA.*)", "Input",
  FormatType->TextForm],

Cell[BoxData[
    \(\(clifflist = Get[\ "\<Cltypes\>"];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(makeclifford[av$cg_, av$cg1_:  12] := \((<< CAV.m; av$34 = av$cg1; 
        av$s50[av$cg]; 
        If[signature == False, Print["\<Invalid signature!\>"]; Return[]]; 
        makescalars[{}]; 
        If[MemberQ[clifflist, 
            av$91], {gammas, omegas, thetas, producttable} = Get[\ \ av$91], 
          av$s51[]]; makeelements[gammas]; makealgebra[producttable]; 
        Clear[producttable]; omdim = Length[omegas]; 
        makeforms[Join[thetas, omegas]]; makethetahat[]; 
        makeomegahat[];)\)\)], "Input",
  InitializationCell->True],

Cell["(*INITIALIZATION PROCEDURES.*)", "Input",
  FormatType->TextForm],

Cell[BoxData[
    \(Unprotect[fmdim, scdim, coordsdim, dscalars]; 
    fmdim = \(scdim = \(coordsdim = 0\)\); dscalars = {}; av$fg = True; \)], 
  "Input",
  InitializationCell->True],

Cell[BoxData[
    \(makeelements[{identity}]; makealgebra[{{identity}}]; makeforms[{}]; 
    makescalars[{}]; \)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(Protect[av$fm, av$s1, av$s3, av$s7, av$s10, av$s12, av$s15, av$s20, 
      av$s21, av$s30, av$s82, av$s83, adL, adR, adjmat, makeelements, 
      makealgebra, makeclifford, makeforms, makeframe, makescalars, 
      makevectors, makecoords, makedrules, associators, generic, in, out, d, 
      da, \[Delta], contract, lie, mult, matmult, coeffs, collect, dot, 
      expand, timer, reset, setzero, hs, applydrules, factor, subspace, 
      pullback, prune, mtx]; \)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(On[Set::wrsym, SetDelayed::write, SetDelayed::wrsym, Syntax::newl]; 
    reset[]; \)], "Input",
  InitializationCell->True]
},
FrontEndVersion->"4.1 for Macintosh",
ScreenRectangle->{{0, 832}, {0, 604}},
AutoGeneratedPackage->Automatic,
ScreenStyleEnvironment->"Working",
WindowSize->{609, 578},
WindowMargins->{{3, Automatic}, {-19, Automatic}},
PrintingCopies->1,
PrintingPageRange->{1, Automatic},
PageHeaders->{{Cell[ 
        TextData[ {
          CounterBox[ "Page"]}], "PageNumber"], Inherited, Cell[ 
        TextData[ {
          ValueBox[ "FileName"]}], "Header"]}, {Cell[ 
        TextData[ {
          ValueBox[ "FileName"]}], "Header"], Inherited, Cell[ 
        TextData[ {
          CounterBox[ "Page"]}], "PageNumber"]}},
PrintingOptions->{"PrintingMargins"->{{54, 54}, {72, 72}},
"PrintCellBrackets"->True,
"PrintRegistrationMarks"->False,
"PrintMultipleHorizontalPages"->False,
"FacingPages"->True},
Magnification->1,
MacintoshSystemPageSetup->"\<\
00<0004/0B`000002n88o?moogl<H`Ue0fL5:0?l0080004/0B`000000]P2:002
0000I00000400`<300000BL?00400@g_G>0000000000060801T1T00000000000
00000000004000000000000000000000\>"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1705, 50, 208, 4, 51, "Input",
  InitializationCell->True],
Cell[1916, 56, 216, 5, 59, "Input",
  InitializationCell->True],
Cell[2135, 63, 97, 2, 27, "Input",
  InitializationCell->True],
Cell[2235, 67, 59, 1, 35, "Input"],
Cell[2297, 70, 67, 1, 27, "Input"],
Cell[2367, 73, 252, 5, 91, "Input",
  InitializationCell->True],
Cell[2622, 80, 824, 16, 187, "Input",
  InitializationCell->True],
Cell[3449, 98, 101, 2, 27, "Input",
  InitializationCell->True],
Cell[3553, 102, 919, 17, 204, "Input",
  InitializationCell->True],
Cell[4475, 121, 59, 1, 34, "Input"],
Cell[4537, 124, 77, 1, 27, "Input"],
Cell[4617, 127, 102, 2, 26, "Input",
  InitializationCell->True],
Cell[4722, 131, 1152, 23, 238, "Input",
  InitializationCell->True],
Cell[5877, 156, 362, 7, 75, "Input",
  InitializationCell->True],
Cell[6242, 165, 409, 8, 101, "Input",
  InitializationCell->True],
Cell[6654, 175, 1758, 33, 404, "Input",
  InitializationCell->True],
Cell[8415, 210, 709, 13, 161, "Input",
  InitializationCell->True],
Cell[9127, 225, 1942, 32, 461, "Input",
  InitializationCell->True],
Cell[11072, 259, 59, 1, 34, "Input"],
Cell[11134, 262, 51, 1, 26, "Input"],
Cell[11188, 265, 397, 8, 86, "Input",
  InitializationCell->True],
Cell[11588, 275, 915, 18, 191, "Input",
  InitializationCell->True],
Cell[12506, 295, 364, 8, 86, "Input",
  InitializationCell->True],
Cell[12873, 305, 528, 13, 101, "Input",
  InitializationCell->True],
Cell[13404, 320, 459, 9, 116, "Input",
  InitializationCell->True],
Cell[13866, 331, 523, 10, 88, "Input",
  InitializationCell->True],
Cell[14392, 343, 201, 4, 43, "Input",
  InitializationCell->True],
Cell[14596, 349, 328, 7, 43, "Input",
  InitializationCell->True],
Cell[14927, 358, 235, 5, 54, "Input",
  InitializationCell->True],
Cell[15165, 365, 810, 16, 88, "Input",
  InitializationCell->True],
Cell[15978, 383, 252, 5, 43, "Input",
  InitializationCell->True],
Cell[16233, 390, 468, 10, 66, "Input",
  InitializationCell->True],
Cell[16704, 402, 666, 14, 99, "Input",
  InitializationCell->True],
Cell[17373, 418, 228, 5, 32, "Input",
  InitializationCell->True],
Cell[17604, 425, 128, 3, 22, "Input",
  InitializationCell->True],
Cell[17735, 430, 305, 6, 55, "Input",
  InitializationCell->True],
Cell[18043, 438, 139, 3, 22, "Input",
  InitializationCell->True],
Cell[18185, 443, 72, 1, 22, "Input"],
Cell[18260, 446, 107, 2, 22, "Input",
  InitializationCell->True],
Cell[18370, 450, 96, 2, 22, "Input",
  InitializationCell->True],
Cell[18469, 454, 504, 11, 66, "Input",
  InitializationCell->True],
Cell[18976, 467, 107, 2, 22, "Input",
  InitializationCell->True],
Cell[19086, 471, 152, 4, 22, "Input",
  InitializationCell->True],
Cell[19241, 477, 754, 15, 88, "Input",
  InitializationCell->True],
Cell[19998, 494, 575, 13, 88, "Input",
  InitializationCell->True],
Cell[20576, 509, 94, 2, 22, "Input",
  InitializationCell->True],
Cell[20673, 513, 149, 3, 22, "Input",
  InitializationCell->True],
Cell[20825, 518, 943, 18, 148, "Input",
  InitializationCell->True],
Cell[21771, 538, 59, 1, 30, "Input"],
Cell[21833, 541, 66, 1, 22, "Input"],
Cell[21902, 544, 341, 9, 43, "Input",
  InitializationCell->True],
Cell[22246, 555, 329, 7, 54, "Input",
  InitializationCell->True],
Cell[22578, 564, 140, 3, 22, "Input",
  InitializationCell->True],
Cell[22721, 569, 169, 4, 22, "Input",
  InitializationCell->True],
Cell[22893, 575, 159, 4, 22, "Input",
  InitializationCell->True],
Cell[23055, 581, 159, 4, 22, "Input",
  InitializationCell->True],
Cell[23217, 587, 162, 4, 22, "Input",
  InitializationCell->True],
Cell[23382, 593, 310, 8, 91, "Input",
  InitializationCell->True],
Cell[23695, 603, 182, 4, 59, "Input",
  InitializationCell->True],
Cell[23880, 609, 357, 9, 91, "Input",
  InitializationCell->True],
Cell[24240, 620, 110, 2, 27, "Input",
  InitializationCell->True],
Cell[24353, 624, 127, 3, 27, "Input",
  InitializationCell->True],
Cell[24483, 629, 338, 7, 75, "Input",
  InitializationCell->True],
Cell[24824, 638, 101, 2, 27, "Input",
  InitializationCell->True],
Cell[24928, 642, 820, 15, 155, "Input",
  InitializationCell->True],
Cell[25751, 659, 75, 1, 27, "Input"],
Cell[25829, 662, 98, 2, 27, "Input",
  InitializationCell->True],
Cell[25930, 666, 573, 11, 139, "Input",
  InitializationCell->True],
Cell[26506, 679, 71, 1, 27, "Input"],
Cell[26580, 682, 183, 4, 59, "Input",
  InitializationCell->True],
Cell[26766, 688, 151, 3, 59, "Input",
  InitializationCell->True],
Cell[26920, 693, 527, 8, 123, "Input",
  InitializationCell->True],
Cell[27450, 703, 143, 3, 43, "Input",
  InitializationCell->True]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

